"""Top-level package for ClinVar This!."""

__author__ = """Manuel Holtgrewe"""
__email__ = "manuel.holtgrewe@bih-charite.de"
__version__ = "0.1.0"

from . import _version

__version__ = _version.get_versions()["version"]
